@@ -14,12 +14,17 @@
  * limitations under the License.
  */
 
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
+/**
+ * @file globus_gram_protocol_io.c
+ * @brief I/O Functions
+ */
+
 #include "globus_i_gram_protocol.h"
 
 #include <string.h>
 
-#ifndef DOXYGEN
-
 static int
 globus_l_gram_protocol_setup_accept_attr(
     globus_io_attr_t *                          attr,
@@ -195,8 +200,9 @@ globus_l_gram_protocol_free_old_credentials();
 
 /**
  * @defgroup globus_gram_protocol_io Message I/O
+ * @brief Mesage I/O
  * @ingroup globus_gram_protocol_functions
- *
+ * @details
  * The functions in this section are related to sending and receiving
  * GRAM protocol messages. 
  */
